# PO1210
#
# Script for PO Purchase Orders.  
# Requires optional fields to exist for the PO order details: BASECOST, FREIGHT, DUTY, IMPORT, EMBROIDERY
# Adds the five optional fields into the PO order entry grid. 
# You can drag & drop them to the left hand side of the grid if required.

from accpac import *

def main(args):
	MyUI()

class MyUI(UI):
	def __init__(self):
		UI.__init__(self)
		self.createScreen()

	def createScreen(self):
		grid = self.getHostControl("vlsPOPORL")
		self.grid = grid

		# Add five new grid fields:
		col = UIGridColumn()
		col.caption = "Container"
		col.hasFinder = True
		col.isEditable = True
		grid.addColumn(col, "DESC")

		grid.setOnFinder(self.onGridFinder)
		grid.setOnBeginEdit(self.onGridBeginEdit)
		grid.setOnAfterEdit(self.onGridAfterEdit)
		
		## Specify the caption of the custom field.
		## This prevents Extender from testing all columns in the grid. Improves performance.
		grid.setOnGetText(self.onGridGetText, "Container")

		self.dsPOPORH = self.openDataSource("dsPOPORH")
		self.dsPOPORL = self.openDataSource("dsPOPORL")
		self.dsPOPORLO = self.openDataSource("dsPOPORLO")
		
		grid.refreshData()
		
		self.onClose = self.checkSaveRecordBeforeClosing
		self.show()

	def onGridBeginEdit(self, e):
		if e.caption == "Container":
			e.datatype = "TEXT"
			e.width = 10
			e.mask = "%-10C"
			self.onGridGetText(e)

	def onGridAfterEdit(self, e):
		if e.caption == "Container":
			self.setOptionalField("CONTAINER", e.value)

	def setOptionalField(self, optfield, value):
		self.dsPOPORLO.put("OPTFIELD", optfield)
		if self.dsPOPORLO.read() == 0:
			self.dsPOPORLO.put("VALUE", value)
			self.dsPOPORLO.update()
		else:
			self.dsPOPORLO.recordGenerate()
			self.dsPOPORLO.put("OPTFIELD", optfield)
			self.dsPOPORLO.put("VALUE", value)
			self.dsPOPORLO.insert()
	
	def getOptionalField(self, optfield):
	
		retVal = "0"
		self.dsPOPORLO.put("OPTFIELD", optfield)
		if self.dsPOPORLO.read() == 0:
			retVal = self.dsPOPORLO.get("VALUE")
			if (retVal == ""):
				retVal = "0"

		return retVal

	def onGridGetText(self, e):
		
		if e.caption == "Container":
			e.value = ""
			self.dsPOPORLO.put("OPTFIELD", "CONTAINER")
			if self.dsPOPORLO.read() == 0:
				e.value = self.dsPOPORLO.get("VALUE")

	def onGridFinder(self, fieldName, caption):
		if caption == "Container":
			finder = Finder()
			finder.viewID = "CS0012"
			finder.displayFields = "2,4"
			finder.returnFields = "2"
			finder.filter = "OPTFIELD=\"CONTAINER\""
			finder.onOK = self.finder_ok
			finder.onCancel = self.finder_cancel
			finder.show(self)

	def finder_ok(self, e):
		self.grid.endEdit(e)

	def finder_cancel(self):
		self.grid.preventFinder()

	############ On closing the P/O UI #####################
	def checkSaveRecordBeforeClosing(self):
		
		if self.dsPOPORH.dirty() != 0:
			# ask the user to save the record.
			self.message("Do you want to post this purchase order?", "Confirmation", "QUESTION", "YESNOCANCEL", self.onConfirmSave)
			
	def onConfirmSave(self, r):
		if r == "YES":
			self.saveRecord()
		elif r == "NO":
			pass
		elif r == "CANCEL":
			# abort closing.
			self.abortClose()
			
	def saveRecord(self):
		self.getHostControl("APP_Post_Button").click()

